from wiringpi import *
import warnings
warnings.simplefilter("always", DeprecationWarning)
warnings.warn("The wiringpi2 module has been deprecated, please 'import wiringpi' instead.", DeprecationWarning, stacklevel=2)
